<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
<xsl:output method="html"/>

<xsl:strip-space elements="*"/>

<xsl:key name="CATALOG_STRUCTURE" match="CATALOG_STRUCTURE" use="PARENT_ID" />
<xsl:key name="ARTICLE" match="/BMECAT/T_NEW_CATALOG/ARTICLE" use="SUPPLIER_AID"/>
<xsl:key name="ARTICLE_TO_CATALOGGROUP_MAP" match="/BMECAT/T_NEW_CATALOG/ARTICLE_TO_CATALOGGROUP_MAP" use="CATALOG_GROUP_ID"/>

<xsl:variable name="mime_root">
	<xsl:if test="/BMECAT/HEADER/CATALOG/MIME_ROOT">
		<xsl:value-of select="concat(/BMECAT/HEADER/CATALOG/MIME_ROOT,'/')" />
	</xsl:if>
</xsl:variable>
<!--
template	showNav
-->
<xsl:template name="showNav">
	<xsl:variable name="root_name" select="/BMECAT/T_NEW_CATALOG/CATALOG_GROUP_SYSTEM/CATALOG_STRUCTURE[@type='root']/GROUP_NAME" />
	<xsl:variable name="root_id" select="/BMECAT/T_NEW_CATALOG/CATALOG_GROUP_SYSTEM/CATALOG_STRUCTURE[@type='root']/GROUP_ID" />
	
	<!--<h1><xsl:value-of select="$root_name" /></h1>-->
	<!-- Rekursiver Aufruf der Funktion rekNav -->
	<xsl:call-template name="rekNav">
		<xsl:with-param name="parent_id" select="$root_id" />
		<xsl:with-param name="level" select="0" />
	</xsl:call-template>
</xsl:template>


<!--
template	rekNav

param		parent_id
param		level
-->
<xsl:template name="rekNav">
	<!-- Funktionsparameter parent_id deklarieren -->
	<xsl:param name="parent_id" />
	<xsl:param name="level" />
	
	<!-- Ausgabe -->
	<ul>
		<xsl:if test="$level=0">
			<xsl:attribute name="id">
				<xsl:text>nav</xsl:text>
			</xsl:attribute>
			<xsl:attribute name="class">
				<xsl:text>qmmc</xsl:text>
			</xsl:attribute>
		</xsl:if>
		
		<xsl:for-each select="key('CATALOG_STRUCTURE', $parent_id)">
			<li>
				<a>
					<xsl:attribute name="href">
						<xsl:text>javascript:showGroup('</xsl:text>
						<xsl:value-of select="GROUP_ID" />
						<xsl:text>');</xsl:text>
					</xsl:attribute>
					<xsl:value-of select="GROUP_NAME" />
				</a>

			<!-- Rekursiver Aufruf der Funktion rekNav -->
			<xsl:call-template name="rekNav">
				<xsl:with-param name="parent_id" select="GROUP_ID" />
				<xsl:with-param name="level" select="$level+1" />
			</xsl:call-template>
			</li>
		</xsl:for-each>
	</ul>
</xsl:template>

<xsl:template name="showCatPic">
	<xsl:for-each select="key('CATALOG_STRUCTURE',//CATALOG_STRUCTURE/PARENT_ID)">
	<xsl:variable name="group_id" select="GROUP_ID" />
	
<!--	<img class="CatImg">
	    <xsl:attribute name="id">
				<xsl:value-of select="$group_id" />
			</xsl:attribute>
		<xsl:attribute name="src">
							<xsl:value-of select="concat('',MIME_INFO/MIME/MIME_SOURCE)"/> 
		</xsl:attribute>	
	</img>
	
	-->		
	</xsl:for-each>
</xsl:template>
<!--
template	showAllCategories
 
-->
<xsl:template name="showAllCategories">
	<!-- Durchlaufe alle Katalog Elemente -->
	<xsl:for-each select="key('CATALOG_STRUCTURE',//CATALOG_STRUCTURE/PARENT_ID)">
		<xsl:variable name="group_id" select="GROUP_ID" />
		<xsl:variable name="group_name" select="GROUP_NAME" />
		
		<span class="catsMap">
			<xsl:attribute name="id">
				<xsl:value-of select="$group_id" />
			</xsl:attribute>
			
			<!-- Informationen der Kategorie -->
			<h2><xsl:value-of select="$group_name" /></h2>
			<!-- Artikelliste in dieser Kategorie -->
		
		
			<table class="tCatArticles">
				<tr>
					<th>Artikelnummer</th>
						<th>Vorschau</th>
					<th>Produktbezeichnung</th>
					<th>Beschreibung</th>
				</tr>
				
				<!-- Durchlaufe alle -->
				<xsl:for-each select="key('ARTICLE_TO_CATALOGGROUP_MAP', $group_id)">
					<!-- Variablen -->
					<xsl:variable name="art_id" select="ART_ID" />
					<xsl:variable name="article" select="key('ARTICLE', $art_id)[1]" />
										
					
					<xsl:variable name="description_short" select="$article/ARTICLE_DETAILS/DESCRIPTION_SHORT" />
					<xsl:variable name="description_long" select="$article/ARTICLE_DETAILS/DESCRIPTION_LONG" />
					<xsl:variable name="price_amount" select="$article/ARTICLE_PRICE_DETAILS/ARTICLE_PRICE/PRICE_AMOUNT" />
					<xsl:variable name="price_currency" select="$article/ARTICLE_PRICE_DETAILS/ARTICLE_PRICE/PRICE_CURRENCY" />
					
					<!-- Ausgabe -->
					<tr>
					    <!-- Linke javascript showArticle -->
						<td>
							<a>
								<xsl:attribute name="href">
									<xsl:text>javascript:showArticle('</xsl:text>
									<xsl:value-of select="$art_id" />
									<xsl:text>');</xsl:text>
									</xsl:attribute>
								<xsl:value-of select="$art_id" />
							</a>
						</td>
						<!-- Vorschau -->
						<td>
						
						<img class="previewImg">
						<xsl:attribute name="src">./bilder/<xsl:value-of select="$article/MIME_INFO/MIME[MIME_PURPOSE='normal']/MIME_SOURCE" />
						</xsl:attribute>
						</img>

    					 </td>
						<!-- Produktbezeichnung -->
						<td>
							<xsl:value-of select="$description_short" />
						</td>
						<!-- Beschreibung -->
						<td>
							<xsl:value-of select="$description_long" disable-output-escaping="yes" />
						</td>
					</tr>
				</xsl:for-each>
			</table>
		</span>
	</xsl:for-each>
	<!-- Ende Durchlaufe alle Katalog Elemente -->
</xsl:template>



<!--
template	showAllArticles

-->
<xsl:template name="showAllArticles">
	<!-- Loop ARTICLE -->
	<xsl:for-each select="key('ARTICLE',//ARTICLE/SUPPLIER_AID)">
		
		<!-- Artikel Information -->
	    <span class="articleInfo">
	    	<xsl:attribute name="id">
				<xsl:value-of select="SUPPLIER_AID" />
			</xsl:attribute>
			
			<p><a href="javascript:showLastCat();">zurück</a></p>
			
			<!-- Bezeichnung -->
			<h1><xsl:value-of select="ARTICLE_DETAILS/DESCRIPTION_SHORT" /></h1>
			
			<!-- Artikelbild -->
			<xsl:choose>
				<xsl:when test="MIME_INFO/MIME[MIME_PURPOSE='thumbnail']">
					<a class="imgLink" target="_blank">
						<xsl:attribute name="href">
							<xsl:value-of select="concat('bilder/', MIME_INFO/MIME[MIME_PURPOSE='normal']/MIME_SOURCE)" />
						</xsl:attribute>
						<img class="articleImg">
							<xsl:attribute name="src">
								<xsl:value-of select="concat('bilder/', MIME_INFO/MIME[MIME_PURPOSE='thumbnail']/MIME_SOURCE)" />
							</xsl:attribute>
						</img>
					</a>
				</xsl:when>
				<xsl:when test="MIME_INFO/MIME[MIME_PURPOSE='normal']">
					<img class="articleImg">
						<xsl:attribute name="src">
							<xsl:value-of select="concat('bilder/', MIME_INFO/MIME[MIME_PURPOSE='normal']/MIME_SOURCE)" />
						</xsl:attribute>
					</img>
				</xsl:when>
				<xsl:otherwise>
					<img class="articleImg">
						<xsl:attribute name="src">
							./imgs/default.jpg
						</xsl:attribute>
					</img>
				</xsl:otherwise>
			</xsl:choose>
			
			         <!-- Warenkorb-->
                
                <br/>
 
                <input size="3">
                    <xsl:attribute name="id">
                    <xsl:text>SID</xsl:text>
                    <xsl:value-of select="SUPPLIER_AID" />
                    </xsl:attribute>
 
                </input>
                <xsl:text>  </xsl:text>
 
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>javascript:addAmount('SID</xsl:text>
                        <xsl:value-of select="SUPPLIER_AID" />

<xsl:text>','</xsl:text>
<xsl:value-of select="SUPPLIER_AID" />
<xsl:text>','</xsl:text>
<xsl:value-of select="ARTICLE_DETAILS/DESCRIPTION_SHORT" />
<xsl:text>','</xsl:text>
<xsl:value-of select="ARTICLE_PRICE_DETAILS/ARTICLE_PRICE/PRICE_AMOUNT" />
<xsl:text>','</xsl:text>
<xsl:value-of select="ARTICLE_PRICE_DETAILS/ARTICLE_PRICE/PRICE_CURRENCY" />



 
                        <xsl:text>');</xsl:text>
                    </xsl:attribute>
                    <xsl:text>In den Warenkorb</xsl:text>
                </a>

                <br/>
                <br/>
 
            <!-- Ende Warenkorb-->
			
			
			
			<!-- ARTICLE_DETAILS: (1) -->
			<h2>Artikelinformationen</h2>
			<hr />
			<table class="ArticleInfo">
				<!-- SUPPLIER_AID (1) -->
				<tr>
					<th>Artikelnummer</th>
					<td><xsl:value-of select="SUPPLIER_AID" /></td>
				</tr>
				<!-- DESCRIPTION_SHORT (1) - Kurzbeschreibung oder Name -->
				<tr>
					<th>Bezeichnung</th>
					<td><xsl:value-of select="ARTICLE_DETAILS/DESCRIPTION_SHORT" /></td>
				</tr>
				<!-- DESCRIPTION_LONG (0...1) - Beschreibung -->
				<tr>
					<th>Beschreibung</th>
					<td><xsl:value-of select="ARTICLE_DETAILS/DESCRIPTION_LONG" disable-output-escaping="yes" /></td>
				</tr>
				<!-- EAN (0..1) - Euro Artnr -->
				<tr>
					<th>EAN</th>
					<td><xsl:value-of select="ARTICLE_DETAILS/EAN" /></td>
				</tr>
				<!-- MANUFACTURER_NAME (0...1) - Herstellername -->
				<tr>
					<th>Hersteller</th>
					<td><xsl:value-of select="ARTICLE_DETAILS/MANUFACTURER_NAME" /></td>
				</tr>
				<!-- MANUFACTURER_TYPE_DESCR (0...1) - Herstellertypbezeichnung -->
				<tr>
					<th>Artikelnr. des Herstellers</th>
					<td><xsl:value-of select="ARTICLE_DETAILS/MANUFACTURER_AID" /></td>
				</tr>
				<!-- DELIVERY_TIME (0...1) - Lieferzeit in Werktagen -->
				<tr>
					<th>Lieferzeit</th>
					<td><xsl:value-of select="ARTICLE_DETAILS/DELIVERY_TIME" /></td>
				</tr>
			</table>
			
			<!-- ARTICLE_PRICE_DETAILS (1...*) -->
			<h2>Preisinformationen</h2>
			<hr />
			<xsl:for-each select="ARTICLE_PRICE_DETAILS">
				<xsl:variable name="price_currency" select="ARTICLE_PRICE/PRICE_CURRENCY" />
				<xsl:variable name="tax" select="ARTICLE_PRICE/TAX" />
				<xsl:variable name="tax_per" select="$tax" />
        			

				
				<!-- Preistyp pruefen -->
				<xsl:variable name="price_type" select="ARTICLE_PRICE/@price_type" />
				<xsl:choose>
					<!-- Listenpreis ohne Umsatzsteuer -->
					<xsl:when test="$price_type='net_list'">
						<h3>Listenpreis ohne Umsatzsteuer</h3>
					</xsl:when>
					
					<!-- Listenpreis mit Umsatzsteuer -->
					<xsl:when test="$price_type='gros_list'">
						<h3>Listenpreis inkl. Umsatzsteuer</h3>
					</xsl:when>
					
					<!-- Kundenspez. Endpreis ohne Umsatzsteuer -->
					<xsl:when test="$price_type='net_customer'">
						<h3>Kundenspezifische Endpreis ohne Umsatzsteuer</h3>
					</xsl:when>
					
					<!-- unverb. Preisempfehlung -->
					<xsl:when test="$price_type='nrp'">
						<h3>unverbindliche Preisempfehlung des Herstellers</h3>
					</xsl:when>
					
					<!-- kundenspez Endpreis ohne Umsatzsteuer bei Expresslieferung -->
					<xsl:when test="$price_type='net_customer_exp'">
						<h3>Kundenspezifischer Endpreis ohne Umsatzsteuer bei Expresslieferung</h3>
					</xsl:when>
					
					<!-- sonst -->
					<xsl:otherwise>
						<h3><xsl:value-of select="$price_type" /></h3>
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- Preis -->
				<xsl:choose>
					<xsl:when test="ARTICLE_PRICE/PRICE_FACTOR">
						<table class="ArticleInfo">
							<tr>
								<th>Preis</th>
								<td><xsl:value-of select="ARTICLE_PRICE/PRICE_AMOUNT * ARTICLE_PRICE/PRICE_FACTOR" />
									<xsl:text> </xsl:text>
									<xsl:value-of select="$price_currency" /></td>
							</tr>
							<tr>
								<th>Umsatzsteuer</th>
								<td>
									<xsl:value-of select="$tax_per" />
									<xsl:text>19%</xsl:text>
								</td>
							</tr>
						</table>
					</xsl:when>
					<xsl:otherwise>
						<table class="ArticleInfo">
							<tr>
								<th>Preis</th>
								<td><xsl:value-of select="ARTICLE_PRICE/PRICE_AMOUNT" />
									<xsl:text> </xsl:text>
									<xsl:value-of select="$price_currency" /></td>
							</tr>
							<tr>
								<th>Umsatzsteuer</th>
								<td>
									<xsl:value-of select="$tax_per" />
									<xsl:text>19%</xsl:text>
								</td>
							</tr>
						</table>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			
			<!-- ARTICLE_FEATURES: (0...*) -->
			<xsl:if test="ARTICLE_FEATURES">
				<h2>Eigenschaften</h2>
				<hr />
				<xsl:for-each select="ARTICLE_FEATURES">
					<!-- REFERENCE_FEATURE_SYSTEM_NAME -->
					<h3><xsl:value-of select="REFERENCE_FEATURE_SYSTEM_NAME" /></h3>
					
					<!-- FEATURES -->
					<table class="ArticleInfo">
					<xsl:for-each select="FEATURE">
						<tr>
							<th><xsl:value-of select="FNAME" /></th>
							<td>
								<xsl:value-of select="FVALUE" />
								<xsl:text> </xsl:text>
								<xsl:value-of select="FUNIT" />
							</td>
						</tr>
					</xsl:for-each>
					</table>
				</xsl:for-each>
			</xsl:if>
			
			<!-- ARTICLE_ORDER_DETAILS (1) -->
			<h2>Bestellinformationen</h2>
			<hr />
			<table class="ArticleInfo">
				<tr>
					<th>Bestelleinheit</th>
					<td><xsl:value-of select="ARTICLE_ORDER_DETAILS/ORDER_UNIT" /></td>
				</tr>
				
				<!-- CONTENT_UNIT -->
				<tr>
					<th>Artikeleinheiten</th>
					<td><xsl:value-of select="ARTICLE_ORDER_DETAILS/CONTENT_UNIT" /></td>
				</tr>
				
				<!-- NO_CU_PER_OU -->
				<tr>
					<th>Anzahl Artikeleinheiten / Bestelleinheit</th>
					<td><xsl:value-of select="ARTICLE_ORDER_DETAILS/NO_CU_PER_OU" /></td>
				</tr>
				
				<!-- PRICE_QUANTITY -->
				<tr>
					<th>Preis bezieht sich auf (Bestelleinheiten)</th>
					<td><xsl:value-of select="ARTICLE_ORDER_DETAILS/PRICE_QUANTITY" /></td>
				</tr>
				
				<!-- QUANTITY_MIN -->
				<tr>
					<th>Mindest Bestelleinheiten</th>
					<td><xsl:value-of select="ARTICLE_ORDER_DETAILS/QUANTITY_MIN" /></td>
				</tr>
				
				<!-- QUANTITY_INTERVAL -->
				<tr>
					<th>Staffelung Bestelleinheiten</th>
					<td><xsl:value-of select="ARTICLE_ORDER_DETAILS/QUANTITY_INTERVAL" /></td>
				</tr>
			</table>
			
			<!-- MIME_INFO (0...1) -->
			<xsl:if test="MIME_INFO">
				<h2>Dateien</h2>
				<hr />
				<!-- Ausgabe PDF Dateien -->
				<xsl:if test="MIME_INFO/MIME[MIME_TYPE='application/pdf']">
						<h3>PDF Dokumente</h3>
						<ul>
						<xsl:for-each select="MIME_INFO/MIME[MIME_TYPE='application/pdf']">
							<li>
							<a target="_blank">
								<xsl:attribute name="href">
									<xsl:value-of select="concat($mime_root, MIME_SOURCE)" />
								</xsl:attribute>
								
								<xsl:attribute name="class">
									<xsl:value-of select="MIME_PURPOSE" />
								</xsl:attribute>
								
								<xsl:value-of select="MIME_DESCR" />
							</a>
							</li>
						</xsl:for-each>
						</ul>
				</xsl:if>
			</xsl:if>
			
			<!-- ARTICLE_REFERENCE (0..*) -->
		</span><!-- Ende Artikel Information -->
	</xsl:for-each><!-- Ende Loop ARTICLE -->
</xsl:template>





<!-- Match das gesamte Dokument -->
<xsl:template match="/">
<html>
	<head>
		<link rel="stylesheet" type="text/css" href="style/bmecat.css" />
		<script src="js/bmecat.js" type="text/javascript"></script>
	</head>

	<body>
		<div id="loaderContainer">
			<p>Katalogdaten werden geladen.</p>
			<img src="style/loader_bar.gif" />
		</div>
		
		<script type="text/javascript">
			loadLoader();
		</script>
		
		<div id="wrapper">
			<div id="header"><a href="#"><img src="./imgs/logo.gif" id="logo"></img></a></div>
		<div id="metanavi">
			&#160;
		</div>

			
			
			<!-- Aufruf der Funktion rekNav -->
			<xsl:call-template name="showNav" />
	
			<!-- Start Content -->
<table>
<tr><td id="content-left">
<div id="CatImg">
<xsl:call-template name="showCatPic" />
<p class="bodytext">Fragen zum BMEcat Viewer:<br/><b>+49 211 51 41 9 75</b><br/>
</p>
<p class="bodytext">Adresse: <br/><b>Sepia GmbH und Co. KG</b><br/>
Ernst-Gnoss-Str. 22<br/>D-40219 Duesseldorf
</p>
<p class="bodytext">E-Mail Anfragen:<br/><b>info@sepia.de</b>
</p>
<p class="bodytext">Webseite:<br/><a href="http://www.sepia.de"><b>www.sepia.de</b></a>
</p>

</div>	


<div id="Warenkorb" style="border: 1px dashed #000000; margin-left:10px; padding:5px" >
<b><xsl:text>Warenkorb </xsl:text></b>
<a>
	<xsl:attribute name="href">
		<xsl:text>javascript:removeElementsfromWK();</xsl:text>
	</xsl:attribute>
    <xsl:text>leeren</xsl:text>
</a>

<br/>

</div>	


<div id="SendWK" style="margin-left:10px; padding:5px" >
<a>
	<xsl:attribute name="href">
		<xsl:text>javascript:sendWK();</xsl:text>
	</xsl:attribute>
    <xsl:text>Bestellung senden</xsl:text>
</a>
<br/>

</div>	


</td>
<td>
			<div id="content">
				<!-- call template showAllCategories -->
				<xsl:call-template name="showAllCategories" />
	
				<!-- call template showAllArticles -->
				<xsl:call-template name="showAllArticles" />
				</div>
</td></tr></table>

		</div>
		
		<div class="spacer" />
		
		<script type="text/javascript">
			unloadLoader();
		</script>
	</body>
</html>

</xsl:template>
</xsl:stylesheet>


